/**
 * @license
 * Original work Copyright Google LLC All Rights Reserved.
 * Modified work Copyright DatePoll-Systems
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
import { BooleanInput } from "@angular/cdk/coercion";
import { EventEmitter, InjectionToken, OnChanges, OnDestroy, OnInit } from "@angular/core";
import { Subject } from "rxjs";
import { SortDirection } from "./sort-direction";
import { HasInitialized } from "../core/initialized";
import { CanDisable } from "../core/disabled";
import * as i0 from "@angular/core";
/** Position of the arrow that displays when sorted. */
export type SortHeaderArrowPosition = 'before' | 'after';
/** Interface for a directive that holds sorting state consumed by `MatSortHeader`. */
export interface NgbSortable {
    /** The id of the column being sorted. */
    id: string;
    /** Starting sort direction. */
    start: SortDirection;
    /** Whether to disable clearing the sorting state. */
    disableClear: boolean;
}
/** The current sort state. */
export interface Sort {
    /** The id of the column being sorted. */
    active: string;
    /** The sort direction. */
    direction: SortDirection;
}
/** Default options for `ngb-sort`.  */
export interface NgbSortDefaultOptions {
    /** Whether to disable clearing the sorting state. */
    disableClear?: boolean;
    /** Position of the arrow that displays when sorted. */
    arrowPosition?: SortHeaderArrowPosition;
}
/** Injection token to be used to override the default options for `mat-sort`. */
export declare const NGB_SORT_DEFAULT_OPTIONS: InjectionToken<NgbSortDefaultOptions>;
/** @docs-private */
declare const _NgbSortBase: (new (...args: any[]) => HasInitialized) & import("../core/constructor").Constructor<CanDisable> & import("../core/constructor").AbstractConstructor<CanDisable> & {
    new (): {};
};
/** Container for NgbSortable to manage the sort state and provide default sort parameters. */
export declare class NgbSort extends _NgbSortBase implements CanDisable, HasInitialized, OnChanges, OnDestroy, OnInit {
    private _defaultOptions?;
    /** Collection of all registered sortables that this directive manages. */
    sortables: Map<string, NgbSortable>;
    /** Used to notify any child components listening to state changes. */
    readonly _stateChanges: Subject<void>;
    /** The id of the most recently sorted MatSortable. */
    active: string;
    /**
     * The direction to set when an MatSortable is initially sorted.
     * May be overriden by the MatSortable's sort start.
     */
    start: SortDirection;
    /** The sort direction of the currently active MatSortable. */
    get direction(): SortDirection;
    set direction(direction: SortDirection);
    private _direction;
    /**
     * Whether to disable the user from clearing the sort by finishing the sort direction cycle.
     * May be overriden by the MatSortable's disable clear input.
     */
    get disableClear(): boolean;
    set disableClear(v: BooleanInput);
    private _disableClear;
    /** Event emitted when the user changes either the active sort or sort direction. */
    readonly sortChange: EventEmitter<Sort>;
    constructor(_defaultOptions?: NgbSortDefaultOptions | undefined);
    /**
     * Register function to be used by the contained NgbSortable. Adds the MatSortable to the
     * collection of NgbSortable.
     */
    register(sortable: NgbSortable): void;
    /**
     * Unregister function to be used by the contained NgbSortable. Removes the MatSortable from the
     * collection of contained NgbSortable.
     */
    deregister(sortable: NgbSortable): void;
    /** Sets the active sort id and determines the new sort direction. */
    sort(sortable: NgbSortable): void;
    /** Returns the next sort direction of the active sortable, checking for potential overrides. */
    getNextSortDirection(sortable: NgbSortable): SortDirection;
    ngOnInit(): void;
    ngOnChanges(): void;
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<NgbSort, [{ optional: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<NgbSort, "[ngb-sort]", ["ngbSort"], { "disabled": { "alias": "ngbSortDisabled"; "required": false; }; "active": { "alias": "ngbSortActive"; "required": false; }; "start": { "alias": "ngbSortStart"; "required": false; }; "direction": { "alias": "ngbSortDirection"; "required": false; }; "disableClear": { "alias": "ngbSortDisableClear"; "required": false; }; }, { "sortChange": "ngbSortChange"; }, never, never, false, never>;
}
export {};
//# sourceMappingURL=sort.d.ts.map